@@ -50,8 +50,6 @@ class table_objects:
         return result[0]
 
     def create(self, *args, **kwargs):
-        if len(kwargs) + 1 != len(self.obj.namespace):
-            raise ValueError("数据与命名域不符.")
         column = self.obj.repo.list_folder(path=self.obj.name, int=True)
         if len(column) == 0:
             column = 0
@@ -59,21 +57,31 @@ class table_objects:
             column = max(column) + 1
         self.obj.repo.make_folder(path=URL(self.obj.name)/column)
 
+        print(self.obj.namespace)
+        input("==="*10)
         datas = []
         for name in self.obj.namespace:
             if name == "id":
                 continue
-
             if name in kwargs:
-                datas.append(kwargs[name])
+                i = (self.obj.namespace.index(name) - 1)
+                if i < 0:
+                    raise ValueError("INDEX 值小于目标阈值，不可跳过.")
+                self.obj.repo.upload_file(
+                    path = URL(self.obj.name) / column / i,
+                    content = json.dumps({"content": kwargs[name]})
+                    )
             else:
-                datas.append(None)
+                raise ValueError("意料之外的参数: %s." % name)
 
-        for i in range(len(datas)):
-            self.obj.repo.upload_file(
-                path = URL(self.obj.name) / column / i,
-                content = json.dumps({"content": datas[i]})
-                )
+        """
+        for i in self.obj.namespace:
+            if name in kwargs:
+                self.obj.repo.upload_file(
+                    path = URL(self.obj.name) / column / i,
+                    content = json.dumps({"content": datas[i]})
+                    )
+        """
         self.obj.sync()
         return self.obj.columns
 
