@@ -1,6 +1,7 @@
 from sqlee.utils.django import models
 from django.forms.models import model_to_dict
 from threading import Thread
+
 import argparse
 import os
 import sqlee
@@ -45,12 +46,11 @@ def migrate():
             print("模块'%s'中未找到SQLEE数据库声明文件." % (app))
             continue
         for model in dir(sqlee_models):
-            model = getattr(eval("sqlee_models"), model)
-            if hasattr(model, "__base__"):
-                print("正在读取Model '%s'" % (model.__name__))
-                if model.__base__ is models.Model:
-                    print("\n正在创建数据表: '%s'\n" % (model().tablename))
-                    repo.objects.create(name=model().tablename, namespace=model().namespaces)
+            model = getattr(sqlee_models, model)
+            if hasattr(model, "repo"):
+                print("正在读取Model '%s'" % (model.__class__.__name__))
+                print("\n正在创建数据表: '%s'\n" % (model.tablename))
+                repo.objects.create(name=model.tablename, namespace=model.namespaces)
     return True
 
 class SYNC_DB(Thread):
@@ -61,7 +61,6 @@ class SYNC_DB(Thread):
         self.tablename = tablename
 
     def run(self):
-        print("线程.")
         self.repo.objects.get(name=self.tablename).objects.create(**self.data)
 
 def format_sql_data(sql_data):
